::+=============================================================================
::
:: Name:        LogSystemInfo.bat
:: Version:		2.6
:: Type:        User Command Task
:: Language:    MS-DOS Batch
:: Index:       Generates running system info useful for diagnosing problems.
::
::
:: Function:
::
::      This procedure is intended to be scheduled to run periodically, and its
::      output can be used by comparison to help determine if something's 
::		running that didn't used to be running, a service config has changed, 
::      a scheduled task has been changed, an update installed, etc.
::
::	    It's useful for ongoing system management.
::
::
:: Synopsis:
::
::      LogSystemInfo
::
::      <No arguments required>
::
::
:: Additional Information:
::
::      This procedure creates a file named for the current date and time, and
::      located in your user profile folder under a Log subfolder 
::      (e.g., C:\Users\username\Log).
::
::      The filename is formatted as follows: SystemInfo_YYYY_MM_DD_HH_MM_SS.log
::
::		The GnuWin32 Toolkit executables gsort, sed, and grep are required.
::		The tool ShowTime written by Noel Carboni is required.
::
::-=============================================================================
::
::  Start of process.
::
		@ECHO OFF
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
::  Check for the required list of command line tools.
::
		which something.that.cannot.be.found.on.this.system >nul 2>&1
		IF ERRORLEVEL 2 ECHO No which in (.;%Path%)
		IF ERRORLEVEL 2 GOTO TOOLS_ERROR
::
		FOR %%T IN (ShowTime,gsort,sed,grep) DO (
			which %%T 2>&1 1>nul
			IF ERRORLEVEL 1 GOTO TOOLS_ERROR
		)
::
		GOTO GOT_TOOLS
::
:TOOLS_ERROR
::
		ECHO.
		ECHO ERROR:  Not all the tools needed could be found either in the folder with the script or in the path.  Unable to continue.
		ECHO.
		GOTO END_OF_PROCEDURE
::
:GOT_TOOLS
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
::  Cover the case where the system is not logged-in.  Use the username this
::   session is being run with.
::
		IF "%USERPROFILE%" == "%SystemDrive%:\Users\Default" SET USERPROFILE=%SystemDrive%:\Users\%USERNAME%
::
::  Create the log folder if it doesn't exist.
::
		MD "%USERPROFILE%\Log" >nul 2>&1
::
::  Set the log filename to be date and time specific.
::
		FOR /F %%a in ('ShowTime %%Y_%%m_%%d_%%H_%%M_%%S') DO SET _SI_Filename=SystemInfo_%%a.log 2>nul
:::		FOR /F %%a in ('powershell -Command "Get-Date -format yyyy_MM_dd_HH_mm_ss"') DO SET _SI_Filename=SystemInfo_%%a.log 2>nul
		IF NOT "%_SI_Filename%" == "" GOTO DO_TL
::
		ECHO.
		ECHO ERROR:  SystemInfo log file name could not be generated.
		ECHO.
		GOTO END_OF_PROCEDURE
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
:DO_TL
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO WMIC path win32_process get name,commandline (show process command lines):>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		WMIC path win32_process get name,commandline /format:csv >"%TEMP%\_SI_ListOfCommandLines.txt"
        TYPE "%TEMP%\_SI_ListOfCommandLines.txt" | sed -r -e "/Node\,CommandLine\,Name/d" -e "/WMIC  path win32_process get name\,commandline \/format\:csv/d" -e "s/^%COMPUTERNAME%\,//" -e "s/^(.*)\,([^,\r]+)[\r]*$/\2\, \1/g" | gsort -f >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO TaskList /V /FO:CSV /NH (processes running):>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		TaskList /V /FO:CSV /NH | gsort -f >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO TaskList /SVC /FO:CSV /NH (services running):>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		TaskList /SVC /FO:CSV /NH | sed -r -e "/\"N\/A\"$/d" | gsort -f >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO TaskList /M /FO:CSV /NH (modules loaded):>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		TaskList /M /FO:CSV /NH | sed -r -e "/\"N\/A\"$/d" | gsort -f >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO PATH (system path from which to run executables):>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		PATH >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO SCHTASKS /Query /FO CSV (states of all scheduled tasks):>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		SCHTASKS /Query /FO CSV | sed -e "/\"TaskName\"\,\"Next Run Time\"\,\"Status\"/d" >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO SC qc (configurations of all services):>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO @ECHO ON >"%TEMP%\_SI_Doit.bat"
		SC query state= all | grep "SERVICE_NAME: " | gsort -f | sed -r -e "s/^SERVICE_NAME: /SC qc \"/g" -e "s/$/\"/g" >>"%TEMP%\_SI_Doit.bat"
		ECHO @ECHO OFF >>"%TEMP%\_SI_Doit.bat"
		CALL "%TEMP%\_SI_Doit.bat" >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO WMIC qfe list (list of all installed updates):>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		WMIC qfe list >"%TEMP%\_SI_ListOfInstalledUpdates.txt"
		TYPE "%TEMP%\_SI_ListOfInstalledUpdates.txt" >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO BCDEDIT /ENUM ALL (list of all boot configuration options):>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		BCDEDIT /ENUM ALL >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
        which autorunsc64 >nul 2>&1
        IF ERRORLEVEL 1 GOTO NO_AUTORUNS
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO autorunsc64 -a * (list of all auto-starting programs):>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		autorunsc64 -a * >"%TEMP%\_SI_Autoruns.log" 2>>"%USERPROFILE%\Log\%_SI_Filename%"
        TYPE "%TEMP%\_SI_Autoruns.log" >>"%USERPROFILE%\Log\%_SI_Filename%"
        DEL "%TEMP%\_SI_Autoruns.log"
		ECHO. >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
:NO_AUTORUNS
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
        which sha1sum >nul 2>&1
        IF ERRORLEVEL 1 GOTO NO_PERFORMANCE_TEST
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		SHOWTIME Checking SHA1 sum of %WINDIR%\System32 and %WINDIR%\SysWOW64 as a performance measurement on %%s>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO.>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO sha1sum "%WINDIR%\System32\*.*" "%WINDIR%\SysWOW64\*.*" 2^>nul ^| sha1sum >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		sha1sum "%WINDIR%\System32\*.*" "%WINDIR%\SysWOW64\*.*" >"%TEMP%\_SI_Hashes.tmp" 2>nul
        type "%TEMP%\_SI_Hashes.tmp" | sha1sum >>"%USERPROFILE%\Log\%_SI_Filename%"
        grep $ -c "%TEMP%\_SI_Hashes.tmp" | sed -e "s/^/Number of files:  /" >>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO.>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
:NO_PERFORMANCE_TEST
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		SHOWTIME LogSystemInfo.bat finished on %%s>>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
		ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_SI_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
:END_OF_PROCEDURE
::
		DEL /Q "%TEMP%\_SI_ListOfCommandLines.txt" "%TEMP%\_SI_Doit.bat" "%TEMP%\_SI_ListOfInstalledUpdates.txt" "%TEMP%\_SI_Hashes.tmp" >nul 2>&1
		SET _SI_Filename=
::
::==============================================================================
::
::  End of file.
::
::==============================================================================
